﻿YCA                                                         MET/CAL Procedure
=============================================================================
INSTRUMENT:            Yokogawa LS3300 Driver V1.0 (GPIB)
DATE:                  2018-03-14 14:24:43
AUTHOR:                Alha  Kane
REVISION:              1.0
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       8
NUMBER OF LINES:       974
=============================================================================
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON
  1.001  ASK+                                          X Z           L
  1.002  ASK-                        P                            F
#*****************************************************************************
#							YOKOGAWA LS3300 DRIVER V1.0
#									**********
# Required MEM: MEM2 = Command String
#				MEM1 = Nominal value to be used in MEMCX
#				@PHASE  = specifies the voltage and current phases
#				@LRATIO = specifies the current and voltage level ratio
#				@WIRING = specifies the wiring mode and wiring priority(optional)
#				@SWEEP  = specifies the sweep time and range (optional)
#				@SRATIO = specifies the sensor ratio value.
#
#	The variables @WIRING and @SWEEP are not reset after each call.
#	To change their value, the user will have to assign a new value to them.
#	The variables @PHASE and @LRATIO are reset to default after each call.
#
# Command String: "FIELD1:FIELD2:FIELD3:FIELD4:FIELD5
# Example:		  "V:RAN 100V:LEV 20V:FREQ 60Hz:LEVR 100"
#	Delimiter = ':'
#	FIELD1	  = Output mode V,C,P
#	FIELD2	  = Range
#	FIELD3	  = Source voltage/current
#	FIELD4	  = Frequency Level
#	FIELD5    = Level Ratio (This field is optional)
#
# Command String: "FIELD1:FIELD2:FIELD3:FIELD4:FIELD5:FIELD6:FIELD7"
#				  "P:RAN 100V:LEV 10V:RAN 10A:LEV 5A:FREQ 60Hz:PF 1 D"
#	Delimiter = ':'
#	FIELD1	  = Output mode V,C,P,CX,PX
#	FIELD2	  = Voltage Range
#	FIELD3	  = Voltage level
#	FIELD4	  = Current Range
#	FIELD5	  = Current Level
#	FIELD6	  = Frequency Level
#	FIELD7    = Power factor (This field is optional). D for lead and G for lag
#
# Command String: "FIELD1:FIELD2"
#				  "VPHASE60:CPHASE90"
#	FIELD1	  = Voltage phase
#	FIELD2    = Current phase
#
# Command String: "FIELD1:FIELD2"
#				  "VRATIO60:CRATIO120"
#	FIELD1	  = Voltage level ratio
#	FIELD2    = Current level ratio
#
# Command String: "FIELD1:FIELD2"
#				  "1P2W:UNIT2"
#   FIELD1	  = Wiring mode
#	FIELD2    = Wiring priority (optional)
#
# Command String: "FIELD1:FIELD2"
#				  "8S:100%"
#   FIELD1	  = Sweep time
#	FIELD2    = Sweep range
#
# Command String: "value mV/A"
#				  "100mV/A"
#
#
#	Delimiter = ':'
#	FIELD1	  = Output mode V,C,P
#	FIELD2	  = Range
#	FIELD3	  = Source voltage/current
#	FIELD4	  = Frequency Level
#	FIELD5    = Level Ratio (This field is optional)
#
#
#	Used Local Registers:
#				L[1] used for local numerical manipulations
#
#	Used Local Variables:
#				MODE:		used to store the output mode
#				WIRE:		used to store the wiring mode
#				RANGE:		used to store the output range
#				OUTLEVEL:	used to store the output level
#				FREQUENCY:	used to store the output frequency
#				VRATIO:		used to store the voltage level ratio
#				CRATIO:		used to store the current level ratio
#				LEV_RATIO:  used to store level ratios for device commands
#				VOLT_OUT:	used to store voltage level for power
#				CURR_OUT:	used to store current level for power
#				VOLT_RANGE:	used to store the voltage range for power
#				CURR_RANGE:	used to store the current range for power
#				SensorRatio:	used to store the sensor ratio value
#				SWEEP_RANGE:	used to store the sweep range value
#				SWEEP_TIME:		used to store the sweep time value
#
#	Used Global Registers:
#				S[32] used as a copy of the command string
#				S[31] used for string manipulations
#				M[252] is an initialization flag.
#
#	Used Global Variables:
#				@PHASE, @LRATIO, @WIRING
#
#	Returns :
#				M[255] -1 or 1 if driver encounters a failure.
#				MEM gets its original value
#				MEM1 gets the nominal value
#
#***************************************

# Copy values stored in MEM registers
  1.003  MATH         S[32] = MEM2
  1.004  MATH         M[254] = MEM1
  1.005  MATH         M[253] = MEM

# Error Flag and other variables Reseting
  1.006  MATH         L[1] = 0
  1.007  MATH         RANGE = 0
  1.008  MATH         OUTLEVEL = 0
  1.009  MATH         FREQUENCY = 0
  1.010  MATH         M[255]= 0
  1.011  MATH         S[32] = MEM2

# Initialization of LS3300
  1.012  IEEE         *CLS[D999]
  1.013  IEEE         *RST[D999]
  1.014  JMPL         No_Initialization_Needed M[252] == 1
  1.015  LABEL        repeat_self_test
  1.016  IEEE         [D2999]*TST? [I]
  1.017  MATH         L[1] = MEM==0
  1.018  JMPL         self_test_performed  MEM==0
  1.019  OPBR         Self Test Failed !
  1.019  OPBR
  1.019  OPBR         Self Test code = [MEM]
  1.019  OPBR
  1.019  OPBR         UNIT may require repair !
  1.019  OPBR
  1.019  OPBR         Do you wish to REPEAT the Self Test ?
  1.020  JMPL         repeat_self_test  MEM1==1
  1.021  LABEL        self_test_performed
  1.022  EVAL   -e MEM == 0:Self Test performed on standard

  2.001  LABEL        No_Initialization_Needed

# Selecting Wiring Mode
  2.002  IF           ISVAR("@WIRING")==1
  2.003  IF           EMPTY(@WIRING)==1
  2.004  MATH         WIRE = "P1W2"
  2.005  ELSEIF       CMPI(STRIP(FLD(@WIRING,1,":")), "1P2W")==1
  2.006  MATH         WIRE = "P1W2"
  2.007  ELSEIF       CMPI(STRIP(FLD(@WIRING,1,":")), "1P2WHC")==1
  2.008  MATH         WIRE = "P1W2HC"
  2.009  ELSEIF       CMPI(STRIP(FLD(@WIRING,1,":")), "1P3W")==1
  2.010  MATH         WIRE = "P1W3"
  2.011  ELSEIF       CMPI(STRIP(FLD(@WIRING,1,":")), "3P3W")==1
  2.012  MATH         WIRE = "P3W3"
  2.013  ELSEIF       CMPI(STRIP(FLD(@WIRING,1,":")), "3P4W")==1
  2.014  MATH         WIRE = "P3W4"
  2.015  ELSEIF       CMPI(STRIP(FLD(@WIRING,1,":")), "3V3A")==1
  2.016  MATH         WIRE = "V3A3"
  2.017  ELSE
  2.018  JMPL         Invalid_Wiring_Mode
  2.019  ENDIF
  2.020  ELSE
  2.021  MATH         WIRE = "P1W2"
  2.022  ENDIF

  2.023  IEEE         :WIRING:TYPE [V WIRE]

  2.024  IF           ISVAR("@WIRING")==1
  2.025  JMPL         No_Priority_Setting EMPTY(FLD(@WIRING, 2,":"))== 1
  2.026  IF           CMPI(FLD(@WIRING, 2,":"), "UNIT2") == 1
  2.027  IEEE         :WIRING:PRIORITY UNIT2
  2.028  ELSEIF       CMPI(FLD(@WIRING, 2,":"), "UNIT3") == 1
  2.029  IEEE         :WIRING:PRIORITY UNIT3
  2.030  ELSE
  2.031  JMPL         Invalid_Wiring_Priority_Setting
  2.032  ENDIF
  2.033  ENDIF
  2.034  LABEL        No_Priority_Setting

# Setting Sweep Time and Range
	# Sweep Time
  2.035  JMPL         No_Sweep_Setting    ISVAR("@SWEEP")==0
  2.036  MATH         MEM = FINDI(FLD(@SWEEP,1,":"),"S",1) != 0
  2.037  MATH         MEM = MEM + IS_NUM_SUB(FLD(@SWEEP,1,":"))
  2.038  JMPL         Missing_Sweep_Time MEM == 0
  2.039  MATH         SWEEP_TIME = NUM(FLD(@SWEEP,1,":"))
  2.040  MATH         L[1] = (SWEEP_TIME !=8 ) && (SWEEP_TIME != 16 )
  2.041  MATH         L[1] = L[1] && (SWEEP_TIME != 32)
  2.042  MATH         L[1] = L[1] && (SWEEP_TIME != 64)
  2.043  JMPL         Invalid_Sweep_Time L[1] == 1
  2.044  IEEE         :SWEEP:TIME [V SWEEP_TIME]S
	# Sweep Range
  2.045  JMPL         No_Sweep_Range_Setting EMPTY(FLD(@SWEEP, 2,":"))== 1
  2.046  MATH         MEM = FINDI(FLD(@SWEEP,2,":"),"%",1) != 0
  2.047  MATH         MEM = MEM + IS_NUM_SUB(FLD(@SWEEP,2,":"))
  2.048  JMPL         Missing_Sweep_Range MEM == 0
  2.049  MATH         SWEEP_RANGE = NUM(FLD(@SWEEP,2,":"))
  2.050  MATH         L[1] = (SWEEP_RANGE !=100 ) && (SWEEP_RANGE != 105 )
  2.051  MATH         L[1] = L[1] && (SWEEP_RANGE != 110)
  2.052  MATH         L[1] = L[1] && (SWEEP_RANGE != 120)
  2.053  JMPL         Invalid_Sweep_Range L[1] == 1
  2.054  IEEE         :SWEEP:RANGE [V SWEEP_RANGE]PCT
  2.055  LABEL        No_Sweep_Range_Setting
  2.056  LABEL        No_Sweep_Setting

# Setting Sensor Ratio Value
  2.057  JMPL         No_Sensor_Ratio_Setting ISVAR("@SRATIO") == 0
  2.058  MATH         MEM = FINDI(@SRATIO,"mV/A",1) != 0
  2.059  MATH         MEM = MEM + IS_NUM_SUB(@SRATIO)
  2.060  JMPL         Invalid_Sensor_Ratio MEM == 0
  2.061  MATH         SensorRatio=NUM(@SRATIO)
  2.062  IF           (SensorRatio <0.0001) || (SensorRatio > 99999.9999)
  2.063  JMPL         Invalid_Sensor_Ratio
  2.064  ENDIF
  2.065  IEEE         :SOURCE:CURRENT:SENSOR:RATIO [V SensorRatio]
  2.066  LABEL        No_Sensor_Ratio_Setting

# Checking Output Mode (FIELD1)
  2.067  MATH         MEM2 = FLD(S[32],1,":")
  2.068  MATH         MEM2 = STRIP(MEM2)
  2.069  JMPL         Volt_Curr_Command_String_Parsing CMPI(MEM2,"C")  == 1
  2.070  JMPL         Volt_Curr_Command_String_Parsing CMPI(MEM2,"V")  == 1
  2.071  JMPL         Volt_Curr_Command_String_Parsing CMPI(MEM2,"CX") == 1
  2.072  JMPL         AC_Power_Command_String_Parsing CMPI(MEM2,"P")   == 1
  2.073  JMPL         AC_Power_Command_String_Parsing CMPI(MEM2,"PX")  == 1
  2.074  JMPL         Missing_MODE_Field

#-----------------------------------------------------
  2.075  LABEL        Volt_Curr_Command_String_Parsing
#-----------------------------------------------------
  2.076  MATH         MODE = MEM2
	# Handling Range (FIELD2)
  2.077  MATH         MEM2 = FLD(S[32],2,":")
  2.078  MATH         MEM = FINDI(MEM2,"RAN",1)
  2.079  JMPL         Missing_RANGE_Field MEM == 0
  2.080  MATH         RANGE = NUM(MEM2)

	# Handling Output Level (FIELD3)
  2.081  MATH         MEM2 = FLD(S[32],3,":")
  2.082  MATH         MEM = FINDI(MEM2,"LEV",1)
  2.083  JMPL         Missing_OUTPUT_Field MEM == 0
  2.084  MATH         OUTLEVEL = NUM(MEM2)

# Range Unit checking
  2.085  MATH         MEM2 = FLD(S[32],2,":")
  2.086  MATH         MEM2 = SUB(MEM2, LEN(MEM2),1)
  2.087  MATH         MEM = FINDI(MEM2,"V",1) + FINDI(MEM2,"A",1)
  2.088  JMPL         Missing_Range_units MEM == 0

# Output Unit checking
  2.089  MATH         MEM2 = FLD(S[32],3,":")
  2.090  MATH         MEM2 = SUB(MEM2, LEN(MEM2),1)
  2.091  MATH         MEM = FINDI(MEM2,"V",1) + FINDI(MEM2,"A",1)
  2.092  JMPL         Missing_Output_units MEM == 0

# Conflicting Unit checking
  2.093  MATH         MEM2 = FLD(S[32],2,":")
  2.094  MATH         MEM2 = SUB(MEM2, LEN(MEM2),1)
  2.095  MATH         S[31] = MEM2
  2.096  MATH         MEM2 = FLD(S[32],3,":")
  2.097  MATH         MEM2 = SUB(MEM2, LEN(MEM2),1)
  2.098  JMPL         Conflicting_units ZCMPI(MEM2,S[31])==0

# Range Unit conversion
  2.099  MATH         MEM2 = FLD(S[32],2,":")
  2.100  MATH         MEM = FINDI(MEM2,"mA",1) + FINDI(MEM2, "mV", 1)
  2.101  IF           MEM != 0
  2.102  MATH         RANGE = RANGE*1E-3
  2.103  ENDIF

# Output Unit conversion (Check out Base, it can be
# a good alternative for conversion)
  2.104  MATH         MEM2 = FLD(S[32],3,":")
  2.105  MATH         MEM = FINDI(MEM2,"mA",1) + FINDI(MEM2,"mV",1)
  2.106  IF           MEM != 0
  2.107  MATH         OUTLEVEL = OUTLEVEL*1E-3
  2.108  ENDIF

# Handling Frequency Level (FIELD 4)
  2.109  MATH         MEM2 = FLD(S[32],4,":")
  2.110  MATH         MEM = FINDI(MEM2,"Hz",1)
  2.111  JMPL         INTERNAL MEM != 0
  2.112  MATH         MEM = FINDI(MEM2,"EXT",1)
  2.113  JMPL         EXTERNAL MEM !=0
  2.114  MATH         MEM = FINDI(MEM2, "LINE",1)
  2.115  JMPL         LINE MEM !=0
  2.116  JMPL         Missing_FREQ_Field
  2.117  LABEL        INTERNAL
  2.118  MATH         MEM = IS_NUM_SUB(MEM2)
  2.119  JMPL         Missing_FREQ_Field MEM == 0
  2.120  MATH         FREQUENCY = NUM(MEM2)
		# Frequency_Range_Value_Check
  2.121  JMPL         Invalid_Freq_value (FREQUENCY>1000) || (FREQUENCY<40)
		# Setting Frequency Level
  2.122  IEEE         :OSCILLATOR:SOURCE INTERNAL
  2.123  IEEE         :OSCILLATOR:FREQUENCY [V FREQUENCY]Hz
  2.124  JMPL         Freq_done
  2.125  LABEL        EXTERNAL
  2.126  IEEE         :OSCILLATOR:SOURCE EXTERNAL
  2.127  JMPL         Freq_done
  2.128  LABEL        LINE
  2.129  IEEE         :OSCILLATOR:SOURCE LINE
  2.130  LABEL        Freq_done

# Handling Level Ratio (FIELD 5)
  2.131  MATH         MEM2 = FLD(S[32],5,":")
  2.132  IF           EMPTY(MEM2) == 0
  2.133  MATH         MEM = FINDI(MEM2,"LEVR",1)
  2.134  JMPL         Missing_LEVR_Field MEM == 0
  2.135  JMPL         Missing_LEVR_Field IS_NUM_SUB(MEM2) == 0
  2.136  MATH         LEV_RATIO = NUM(MEM2)
  2.137  JMPL         Invalid_LEVR_Field (LEV_RATIO>120) || (LEV_RATIO)<0
  2.138  ELSE
  2.139  MATH         LEV_RATIO =100
  2.140  ENDIF
  2.141  JMPL         Actual_Command_Run
#----------------------------------------------------
  2.142  LABEL        AC_Power_Command_String_Parsing
#----------------------------------------------------

  2.143  MATH         MODE = MEM2
	# Handling Voltage (FIELD 2 & FIELD 3)
		# Voltage Range
  2.144  MATH         MEM2 = FLD(S[32],2,":")
  2.145  MATH         MEM = FINDI(MEM2,"RAN",1)
  2.146  JMPL         Missing_RANGE_Field MEM ==0
  2.147  MATH         MEM = IS_NUM_SUB(MEM2)
  2.148  JMPL         Missing_RANGE_Field MEM == 0
		# Range Unit checking
  2.149  MATH         MEM = FINDI(MEM2,"V",1)
  2.150  JMPL         Missing_Range_units MEM == 0
  2.151  MATH         VOLT_RANGE = NUM(MEM2)
		# Range Unit conversion
  2.152  MATH         MEM = FINDI(MEM2,"mV",1)
  2.153  IF           MEM != 0
  2.154  MATH         VOLT_RANGE = VOLT_RANGE*1E-3
  2.155  ENDIF
		# Voltage Output
  2.156  MATH         MEM2 = FLD(S[32],3,":")
  2.157  MATH         MEM = FINDI(MEM2,"LEV",1)
  2.158  JMPL         Missing_OUTPUT_Field MEM ==0
  2.159  MATH         MEM = IS_NUM_SUB(MEM2)
  2.160  JMPL         Missing_OUTPUT_Field MEM == 0
		# Output Unit Checking
  2.161  MATH         MEM = FINDI(MEM2,"V",1)
  2.162  JMPL         Missing_Output_units MEM == 0
  2.163  MATH         VOLT_OUTPUT = NUM(MEM2)
		# Output Unit Conversion
  2.164  MATH         MEM = FINDI(MEM2,"mV",1)
  2.165  IF           MEM != 0
  2.166  MATH         VOLT_OUTPUT = VOLT_OUTPUT*1E-3
  2.167  ENDIF
	# Handling Current (FIELD 4 & FIELD 5)
		# Current Range
  2.168  MATH         MEM2 = FLD(S[32],4,":")
  2.169  MATH         MEM = FINDI(MEM2,"RAN",1)
  2.170  JMPL         Missing_RANGE_Field MEM ==0
  2.171  MATH         MEM = IS_NUM_SUB(MEM2)
  2.172  JMPL         Missing_RANGE_Field MEM == 0

		# Regular Current Mode
  2.173  JMPL         AUX_POWER_RANGE_MODE CMPI(MODE, "PX") == 1
		# Range Unit checking
  2.174  MATH         MEM = FINDI(MEM2,"A",1)
  2.175  JMPL         Missing_Range_units MEM == 0
  2.176  MATH         CURR_RANGE = NUM(MEM2)
		# Range Unit conversion
  2.177  MATH         MEM = FINDI(MEM2,"mA",1)
  2.178  IF           MEM != 0
  2.179  MATH         CURR_RANGE = CURR_RANGE*1E-3
  2.180  ENDIF
  2.181  JMPL         POWER_RANGE_DONE
  2.182  LABEL        AUX_POWER_RANGE_MODE
		# Range Unit checking
  2.183  MATH         MEM = FINDI(MEM2,"V",1)
  2.184  JMPL         Missing_Range_units_AUX MEM == 0
  2.185  MATH         CURR_RANGE = NUM(MEM2)
		# Range Unit conversion
  2.186  MATH         MEM = FINDI(MEM2,"mV",1)
  2.187  IF           MEM != 0
  2.188  MATH         CURR_RANGE = CURR_RANGE*1E-3
  2.189  ENDIF
  2.190  LABEL        POWER_RANGE_DONE
		# Current Output
  2.191  MATH         MEM2 = FLD(S[32],5,":")
  2.192  MATH         MEM = FINDI(MEM2,"LEV",1)
  2.193  JMPL         Missing_OUTPUT_Field MEM ==0
  2.194  MATH         MEM = IS_NUM_SUB(MEM2)
  2.195  JMPL         Missing_OUTPUT_Field MEM == 0

  2.196  JMPL         AUX_POWER_OUTPUT_MODE CMPI(MODE, "PX") == 1
		# Output Unit Checking
  2.197  MATH         MEM = FINDI(MEM2,"A",1)
  2.198  JMPL         Missing_Output_units MEM == 0
  2.199  MATH         CURR_OUTPUT = NUM(MEM2)
		# Output Unit Conversion
  2.200  MATH         MEM = FINDI(MEM2,"mA",1)
  2.201  IF           MEM != 0
  2.202  MATH         CURR_OUTPUT = CURR_OUTPUT*1E-3
  2.203  ENDIF
  2.204  JMPL         POWER_OUTPUT_DONE
  2.205  LABEL        AUX_POWER_OUTPUT_MODE
		# Output Unit Checking
  2.206  MATH         MEM = FINDI(MEM2,"V",1)
  2.207  JMPL         Missing_Output_units_AUX MEM == 0
  2.208  MATH         CURR_OUTPUT = NUM(MEM2)
		# Output Unit Conversion
  2.209  MATH         MEM = FINDI(MEM2,"mV",1)
  2.210  IF           MEM != 0
  2.211  MATH         CURR_OUTPUT = CURR_OUTPUT*1E-3
  2.212  ENDIF
  2.213  LABEL        POWER_OUTPUT_DONE
	# Frequency Level (FIELD 6)
  2.214  MATH         MEM2 = FLD(S[32],6,":")
  2.215  MATH         MEM = FINDI(MEM2,"Hz",1)
  2.216  JMPL         P_INTERNAL MEM !=0
  2.217  MATH         MEM = FINDI(MEM2,"EXT",1)
  2.218  JMPL         P_EXTERNAL MEM != 0
  2.219  MATH         MEM = FINDI(MEM2, "LINE",1)
  2.220  JMPL         P_LINE MEM !=0
  2.221  JMPL         Missing_FREQ_Field
  2.222  LABEL        P_INTERNAL
  2.223  MATH         MEM = IS_NUM_SUB(MEM2)
  2.224  JMPL         Missing_FREQ_Field MEM == 0
  2.225  MATH         FREQUENCY = NUM(MEM2)
		# Frequency_Range_Value_Check
  2.226  JMPL         Invalid_Freq_value (FREQUENCY>1000) || (FREQUENCY<40)
		# Setting Frequency Level
  2.227  IEEE         :OSCILLATOR:SOURCE INTERNAL
  2.228  IEEE         :OSCILLATOR:FREQUENCY [V FREQUENCY]Hz
  2.229  JMPL         P_Freq_done
  2.230  LABEL        P_EXTERNAL
  2.231  IEEE         :OSCILLATOR:SOURCE EXTERNAL
  2.232  JMPL         P_Freq_done
  2.233  LABEL        P_LINE
  2.234  IEEE         :OSCILLATOR:SOURCE LINE
  2.235  LABEL        P_Freq_done

	# Power Factor (FIELD 7)
  2.236  MATH         MEM2 = FLD(S[32],7,":")
  2.237  IF           EMPTY(MEM2) == 0
  2.238  MATH         MEM = IS_NUM_SUB(MEM2)
  2.239  JMPL         Invalid_Power_Factor_Field MEM == 0
  2.240  MATH         PFACTOR = NUM(MEM2)
  2.241  JMPL         Invalid_Power_Factor_Field (PFACTOR > 1) || (PFACTOR)<-1
		#Power Factor Polarity
  2.242  MATH         MEM = FINDI(MEM2,"D",1)
  2.243  MATH         MEM1 = FINDI(MEM2,"G",1)
			#IF STATEMENT 2
  2.244  IF           MEM != 0
  2.245  MATH         POLARITY = "LEAD"
  2.246  ELSEIF       MEM1 != 0
  2.247  MATH         POLARITY = "LAG"
  2.248  ELSE
  2.249  JMPL         Missing_Power_Factor_Polarity
  2.250  ENDIF
			#ENDIF STATEMENT 2
  2.251  ELSE
  2.252  MATH         PFACTOR = 1
  2.253  MATH         POLARITY = "LAG"
  2.254  ENDIF

# Handling Voltage and Current Phase
  2.255  IF           ISVAR("@PHASE") == 1
  2.256  IF           CMPI(@PHASE,"NULL")!= 1
	# Voltage Phase
  2.257  MATH         MEM2 = FLD(@PHASE,1,":")
  2.258  MATH         MEM = FINDI(MEM2,"VPHASE",1) != 0
  2.259  MATH         MEM = MEM + IS_NUM_SUB(MEM2)
  2.260  JMPL         Invalid_Voltage_Phase MEM == 0
  2.261  MATH         VPHASE = NUM(MEM2)
	# Current Phase
  2.262  MATH         MEM2 = FLD(@PHASE,2,":")
  2.263  MATH         MEM = FINDI(MEM2,"CPHASE",1) != 0
  2.264  MATH         MEM = MEM + IS_NUM_SUB(MEM2)
  2.265  JMPL         Invalid_Current_Phase MEM == 0
  2.266  MATH         CPHASE = NUM(MEM2)
  2.267  ENDIF
  2.268  ENDIF

# Handling Voltage and Current Level Ratio for Power
  2.269  IF           ISVAR("@LRATIO")==1
	# Voltage Level Ratio
  2.270  MATH         MEM2 = FLD(@LRATIO,1,":")
  2.271  MATH         MEM = FINDI(MEM2,"VRATIO",1) != 0
  2.272  MATH         MEM = MEM + IS_NUM_SUB(MEM2)
  2.273  JMPL         Missing_Voltage_LRATIO MEM == 0
  2.274  MATH         VRATIO = NUM(MEM2)
  2.275  JMPL         Invalid_Voltage_LRATIO (VRATIO<0 || VRATIO>120)
	# Current Level Ratio
  2.276  MATH         MEM2 = FLD(@LRATIO,2,":")
  2.277  MATH         MEM = FINDI(MEM2,"CRATIO",1) != 0
  2.278  MATH         MEM = MEM + IS_NUM_SUB(MEM2)
  2.279  JMPL         Missing_Current_LRATIO MEM == 0
  2.280  MATH         CRATIO = NUM(MEM2)
  2.281  JMPL         Invalid_Current_LRATIO (CRATIO<0 || CRATIO>120)
  2.282  ELSE
  2.283  MATH         VRATIO =100
  2.284  MATH         CRATIO = 100
  2.285  ENDIF
#-------------------------------------------
  2.286  LABEL        Actual_Command_Run
#-------------------------------------------
	# Handling Mode (FIELD1)
  2.287  MATH         MEM2 = FLD(S[32],1,":")
  2.288  JMPL         AC_Current_Output CMPI(MODE,"C") == 1
  2.289  JMPL         AC_Current_Output CMPI(MODE,"CX") == 1
  2.290  JMPL         AC_Voltage_Output CMPI(MODE,"V") == 1
  2.291  JMPL         AC_Power CMPI(MODE,"P") == 1
  2.292  JMPL         AC_Power CMPI(MODE,"PX") == 1

  2.293  EVAL   NEW_STEP_NUMBER
  3.001  MATH         M[255] = 0
#--------------------------------------------------
  3.002  LABEL        AC_Power
#--------------------------------------------------
# Setting power factor
  3.003  IEEE         :SOURCE:PFACTOR:POLARITY [V POLARITY]
  3.003  IEEE         :SOURCE:PFACTOR:VALUE [V PFACTOR]
# Setting output phase shift
  3.004  IF           ISVAR("@PHASE") == 1
  3.005  IF           CMPI(@PHASE,"NULL") !=1
  3.006  IEEE         :SOURCE:CURRENT:PHASE:VALUE [V CPHASE]
  3.007  IEEE         :SOURCE:VOLTAGE:PHASE:VALUE [V VPHASE]
  3.008  ENDIF
  3.009  ENDIF
# Setting output values
  3.010  MATH         RANGE = VOLT_RANGE
  3.011  MATH         OUTLEVEL = VOLT_OUTPUT
  3.012  MATH         LEV_RATIO = VRATIO
  3.013  JMPL         AC_Voltage_Output
  3.014  LABEL        AC_Power_Current_Out
  3.015  MATH         RANGE = CURR_RANGE
  3.016  MATH         OUTLEVEL = CURR_OUTPUT
  3.017  MATH         LEV_RATIO = CRATIO
  3.018  JMPL         AC_Current_Output

  3.019  EVAL   NEW_STEP_NUMBER
  4.001  MATH         M[255] = 0
#----------------------------------------------
  4.002  LABEL        AC_Voltage_Output
#-----------------------------------------------
#  Voltage_Range_Value_Check
  4.003  MATH         L[1] = (RANGE != 1) && (RANGE != 10)
  4.004  MATH         L[1] = L[1] && (RANGE !=30)
  4.005  MATH         L[1] = L[1] && (RANGE != 100)
  4.006  MATH         L[1] = L[1] && (RANGE != 300)
  4.007  MATH         L[1] = L[1] && (RANGE != 1000)
  4.008  JMPL         Invalid_Range L[1] == 1

#	Voltage Output Level
  4.009  IF           RANGE == 1
  4.010  JMPL         Invalid_Voltage_Level (OUTLEVEL>1.2) || (OUTLEVEL<1E-4)
  4.011  ELSEIF       RANGE == 10
  4.012  JMPL         Invalid_Voltage_Level (OUTLEVEL>12) || (OUTLEVEL<1E-3)
  4.013  ELSEIF       RANGE == 100
  4.014  JMPL         Invalid_Voltage_Level (OUTLEVEL>120) || (OUTLEVEL<1E-2)
  4.015  ELSEIF       RANGE == 300
  4.016  JMPL         Invalid_Voltage_Level (OUTLEVEL>360) || (OUTLEVEL<1E-1)
  4.017  ELSEIF       RANGE == 1000
  4.018  JMPL         Invalid_Voltage_Level (OUTLEVEL>1200) || (OUTLEVEL<1E-1)
  4.019  ENDIF

  4.020  IEEE         :SOURCE:VOLTAGE:RANGE [V RANGE]V
  4.021  IEEE         :SOURCE:VOLTAGE:LEVEL:RATIO [V LEV_RATIO]
  4.022  IEEE         :SOURCE:VOLTAGE:LEVEL [V OUTLEVEL]V
  4.023  IEEE         :OUTPUT:SELECT:VOLTAGE1 ON
  4.024  IEEE         :OUTPUT ON [D2999]
  4.025  IEEE         :OUTPUT? [I]
  4.026  IEEE         :STATUS:ERROR? [I$]
  4.027  JMPL         ERROR_CHECKING_DONE    MEM != 0
  4.028  IF           CMPI(FLD(MEM2,1,","), "0") != 1
  4.029  MATH         S[31] = FLD(MEM2,1,".")
  4.030  DISP         Error code:[S31]."
  4.031  ENDIF
  4.032  MATH         M[255] = -1
  4.033  EVAL   -e M[255] ==0:Connection Error...
  5.001  MATH         MEM=MEM
  5.002  LABEL        ERROR_CHECKING_DONE
  5.003  JMPL         AC_Power_Current_Out CMPI(MODE,"P") == 1
  5.004  JMPL         AC_Power_Current_Out CMPI(MODE,"PX") == 1
  5.005  JMPL         EXIT_SUB

  5.006  EVAL   NEW_STEP_NUMBER
  6.001  MATH         M[255] = 0
#-----------------------------------------------
  6.002  LABEL        AC_Current_Output
#-----------------------------------------------
  6.003  JMPL         AUX_MODE_OUT CMPI(MODE, "CX") == 1
  6.004  JMPL         AUX_MODE_OUT CMPI(MODE, "PX") == 1
#  Current_Range_Value_Check
  6.005  MATH         L[1] = (RANGE != 1) && (RANGE != 10)
  6.006  MATH         L[1] = L[1] && (RANGE != 50)
  6.007  MATH         L[1] = L[1] && (RANGE != 100E-3)
  6.008  MATH         L[1] = L[1] && (RANGE != 30E-3)
  6.009  JMPL         Invalid_Range L[1] == 1

#	Current Output Level
  6.010  IF           RANGE == 30E-3
  6.011  JMPL         Invalid_Curr_Level (OUTLEVEL>36E-3) || (OUTLEVEL<1E-7)
  6.012  ELSEIF       RANGE == 100E-3
  6.013  JMPL         Invalid_Curr_Level (OUTLEVEL>.120) || (OUTLEVEL<1E-6)
  6.014  ELSEIF       RANGE == 1
  6.015  JMPL         Invalid_Curr_Level (OUTLEVEL>1.2) || (OUTLEVEL<1E-5)
  6.016  ELSEIF       RANGE == 10
  6.017  JMPL         Invalid_Curr_Level (OUTLEVEL>12) || (OUTLEVEL<1E-4)
  6.018  ELSE
  6.019  JMPL         Invalid_Curr_Level (OUTLEVEL>60) || (OUTLEVEL<1E-3)
  6.020  ENDIF

  6.021  LABEL        OUTPUT_CURRENT
  6.022  IF           (CMPI(MODE, "CX") == 1) || (CMPI(MODE, "PX")==1)
  6.023  IEEE         :SOURCE:CURRENT:RANGE AUX, [V RANGE]V
  6.024  IEEE         :SOURCE:CURRENT:LEVEL [V OUTLEVEL]V
  6.025  ELSE
  6.026  IEEE         :SOURCE:CURRENT:RANGE [V RANGE]A
  6.027  IEEE         :SOURCE:CURRENT:LEVEL [V OUTLEVEL]A
  6.028  ENDIF
  6.029  IEEE         :SOURCE:CURRENT:LEVEL:RATIO [V LEV_RATIO]
  6.030  IEEE         :OUTPUT:SELECT:CURRENT1 ON
  6.031  IEEE         :OUTPUT ON [D2999]
  6.032  IEEE         :OUTPUT? [I]
  6.033  IEEE         :STATUS:ERROR? [I$]
  6.034  JMPL         EXIT_SUB    MEM != 0
  6.035  IF           CMPI(FLD(MEM2,1,","), "0") != 1
  6.036  MATH         S[31] = FLD(MEM2,1,".")
  6.037  DISP         Error code:[S31]."
  6.038  ENDIF
  6.039  MATH         M[255] = -1
  6.040  EVAL   -e M[255] ==0:Connection Error...
  7.001  MATH         MEM=MEM
  7.002  JMPL         EXIT_SUB

  7.003  LABEL        AUX_MODE_OUT
#  AUX_Voltage_Range_Value_Check
  7.004  MATH         L[1] = (RANGE != 500E-3) && (RANGE != 5)
  7.005  JMPL         Invalid_Range_IN_AUX L[1] == 1
#  AUX_Voltage_Level_Value_Check
  7.006  IF           RANGE == 500E-3
  7.007  JMPL         Invalid_AUX_Level (OUTLEVEL>600E-3) || (OUTLEVEL<1E-5)
  7.008  ELSEIF       RANGE == 5
  7.009  JMPL         Invalid_AUX_Level (OUTLEVEL>6.0) || (OUTLEVEL<1E-4)
  7.010  ENDIF
  7.011  JMPL         OUTPUT_CURRENT

#######################################################################
# Error_Handling_Messages											  #
#######################################################################

  7.012  LABEL        Missing_MODE_Field
  7.013  MATH         M[255]=1
  7.014  DISP         Yokogawa LS3300 Driver
  7.014  DISP
  7.014  DISP         ERROR...!
  7.014  DISP         Output Mode is missing or incorrectly specified.
  7.015  JMPL         EXIT_SUB

  7.016  LABEL        Missing_Range_units
  7.017  MATH         M[255]=1
  7.018  DISP         Yokogawa LS3300 Driver
  7.018  DISP
  7.018  DISP         ERROR...!
  7.018  DISP         Range units is missing or incorrectly specified.
  7.019  JMPL         EXIT_SUB

  7.020  LABEL        Missing_Range_units_AUX
  7.021  MATH         M[255]=1
  7.022  DISP         Yokogawa LS3300 Driver
  7.022  DISP
  7.022  DISP         ERROR...!
  7.022  DISP         Range units is missing or incorrectly specified.
  7.022  DISP         Range units must be V or mV in AUX mode.
  7.023  JMPL         EXIT_SUB

  7.024  LABEL        Missing_Output_units
  7.025  MATH         M[255]=1
  7.026  DISP         Yokogawa LS3300 Driver
  7.026  DISP
  7.026  DISP         ERROR...!
  7.026  DISP         Level units is missing or incorrectly specified.
  7.027  JMPL         EXIT_SUB

  7.028  LABEL        Missing_Output_units_AUX
  7.029  MATH         M[255]=1
  7.030  DISP         Yokogawa LS3300 Driver
  7.030  DISP
  7.030  DISP         ERROR...!
  7.030  DISP         Level units is missing or incorrectly specified.
  7.030  DISP         Level units must be V or mV in AUX mode
  7.031  JMPL         EXIT_SUB

  7.032  LABEL        Conflicting_units
  7.033  MATH         M[255]=1
  7.034  DISP         Yokogawa LS3300 Driver
  7.034  DISP
  7.034  DISP         ERROR...!
  7.034  DISP         Conflicting range and output units.
  7.035  JMPL         EXIT_SUB

  7.036  LABEL        Missing_RANGE_Field
  7.037  MATH         M[255]=1
  7.038  DISP         Yokogawa LS3300 Driver
  7.038  DISP
  7.038  DISP         ERROR...!
  7.038  DISP         Range field is missing or incorrectly specified.
  7.039  JMPL         EXIT_SUB

  7.040  LABEL        Missing_OUTPUT_Field
  7.041  MATH         M[255]=1
  7.042  DISP         Yokogawa LS3300 Driver
  7.042  DISP
  7.042  DISP         ERROR...!
  7.042  DISP         Output field is missing or incorrectly specified.
  7.043  JMPL         EXIT_SUB

  7.044  LABEL        Missing_FREQ_Field
  7.045  MATH         M[255]=1
  7.046  DISP         Yokogawa LS3300 Driver
  7.046  DISP
  7.046  DISP         ERROR...!
  7.046  DISP         Frequency field is missing or incorrectly specified.
  7.047  JMPL         EXIT_SUB

  7.048  LABEL        Missing_LEVR_Field
  7.049  MATH         M[255]=1
  7.050  DISP         Yokogawa LS3300 Driver
  7.050  DISP
  7.050  DISP         ERROR...!
  7.050  DISP         Level Ratio field is missing or incorrectly specified.
  7.051  JMPL         EXIT_SUB

  7.052  LABEL        Invalid_Power_Factor_Field
  7.053  MATH         M[255]=1
  7.054  DISP         Yokogawa LS3300 Driver
  7.054  DISP
  7.054  DISP         ERROR...!
  7.054  DISP         Power Factor field is missing or incorrectly specified.
  7.055  JMPL         EXIT_SUB

  7.056  LABEL        Missing_Power_Factor_Polarity
  7.057  MATH         M[255]=1
  7.058  DISP         Yokogawa LS3300 Driver
  7.058  DISP
  7.058  DISP         ERROR...!
  7.058  DISP         Lead/Lag polarity is missing or incorrectly specified.
  7.059  JMPL         EXIT_SUB

  7.060  LABEL        Missing_Current_LRATIO
  7.061  MATH         M[255]=1
  7.062  DISP         Yokogawa LS3300 Driver
  7.062  DISP
  7.062  DISP         ERROR...!
  7.062  DISP         Current Level Ratio is missing or incorrectly specified.
  7.063  JMPL         EXIT_SUB

  7.064  LABEL        Missing_Voltage_LRATIO
  7.065  MATH         M[255]=1
  7.066  DISP         Yokogawa LS3300 Driver
  7.066  DISP
  7.066  DISP         ERROR...!
  7.066  DISP         Voltage Level Ratio is missing or incorrectly specified.
  7.067  JMPL         EXIT_SUB

  7.068  LABEL        Invalid_Voltage_Phase
  7.069  MATH         M[255]=1
  7.070  DISP         Yokogawa LS3300 Driver
  7.070  DISP
  7.070  DISP         ERROR...!
  7.070  DISP         Voltage phase is missing or incorrectly specified.
  7.071  JMPL         EXIT_SUB

  7.072  LABEL        Invalid_Current_Phase
  7.073  MATH         M[255]=1
  7.074  DISP         Yokogawa LS3300 Driver
  7.074  DISP
  7.074  DISP         ERROR...!
  7.074  DISP         Current phase is missing or incorrectly specified.
  7.075  JMPL         EXIT_SUB

  7.076  LABEL        Missing_Sweep_Time
  7.077  MATH         M[255]=1
  7.078  DISP         Yokogawa LS3300 Driver
  7.078  DISP
  7.078  DISP         ERROR...!
  7.078  DISP         Sweep Time field missing or incorrectly specified.
  7.079  JMPL         EXIT_SUB

  7.080  LABEL        Missing_Sweep_Range
  7.081  MATH         M[255]=1
  7.082  DISP         Yokogawa LS3300 Driver
  7.082  DISP
  7.082  DISP         ERROR...!
  7.082  DISP         Sweep Range field missing or incorrectly specified.
  7.083  JMPL         EXIT_SUB

  7.084  LABEL        Invalid_Sweep_Time
  7.085  MATH         M[255]=1
  7.086  DISP         Yokogawa LS3300 Driver
  7.086  DISP
  7.086  DISP         ERROR...!
  7.086  DISP         Sweep time is incorrectly specified.
  7.086  DISP         The allowed sweep times are 8s, 16s, 32s, and 64s.
  7.087  JMPL         EXIT_SUB

  7.088  LABEL        Invalid_Sweep_Range
  7.089  MATH         M[255]=1
  7.090  DISP         Yokogawa LS3300 Driver
  7.090  DISP
  7.090  DISP         ERROR...!
  7.090  DISP         Sweep range is incorrectly specified.
  7.090  DISP         The allowed sweep ranges are 100, 105, 110, and 120 (%).
  7.091  JMPL         EXIT_SUB

  7.092  LABEL        Invalid_Sensor_Ratio
  7.093  MATH         M[255]=1
  7.094  DISP         Yokogawa LS3300 Driver
  7.094  DISP
  7.094  DISP         ERROR...!
  7.094  DISP         Sensor ratio level is incorrectly specified.
  7.094  DISP         The selectable values are from 0.0001 to 99999.9999 mV/A
  7.095  JMPL         EXIT_SUB

  7.096  LABEL        Ivalid_Oscillator_Setting
  7.097  MATH         M[255]=1
  7.098  DISP         Yokogawa LS3300 Driver
  7.098  DISP
  7.098  DISP         ERROR...!
  7.098  DISP         The Oscillator source mode is incorrectly specified.
  7.099  DISP         The allowed modes are "INTERNAL", "EXTERNAL" and "LINE".
  7.100  JMPL         EXIT_SUB

  7.101  LABEL        Invalid_Voltage_Level
  7.102  MATH         M[255]=1
  7.103  DISP         Yokogawa LS3300 Driver
  7.103  DISP
  7.103  DISP         ERROR...!
  7.103  DISP         Voltage level exceeds range limits.
  7.104  JMPL         EXIT_SUB

  7.105  LABEL        Invalid_Curr_Level
  7.106  MATH         M[255]=1
  7.107  DISP         Yokogawa LS3300 Driver
  7.107  DISP
  7.107  DISP         ERROR...!
  7.107  DISP         Current level exceeds range limits.
  7.108  JMPL         EXIT_SUB

  7.109  LABEL        Invalid_AUX_Level
  7.110  MATH         M[255]=1
  7.111  DISP         Yokogawa LS3300 Driver
  7.111  DISP
  7.111  DISP         ERROR...!
  7.111  DISP         Aux voltage level exceeds range limits.
  7.112  JMPL         EXIT_SUB

  7.113  LABEL        Invalid_Range
  7.114  MATH         M[255]=1
  7.115  DISP         Yokogawa LS3300 Driver
  7.115  DISP
  7.115  DISP         ERROR...!
  7.115  DISP         Invalid Voltage or Current Range.
  7.116  JMPL         EXIT_SUB

  7.117  LABEL        Invalid_Range_IN_AUX
  7.118  MATH         M[255]=1
  7.119  DISP         Yokogawa LS3300 Driver
  7.119  DISP
  7.119  DISP         ERROR...!
  7.119  DISP         Invalid Range in AUX mode. Allowed ranges are 500mV & 5V
  7.120  JMPL         EXIT_SUB

  7.121  LABEL        Invalid_Wiring_Mode
  7.122  MATH         M[255]=1
  7.123  DISP         Yokogawa LS3300 Driver
  7.123  DISP
  7.123  DISP         ERROR...!
  7.123  DISP         Wiring mode incorrectly specified.
  7.124  JMPL         EXIT_SUB

  7.125  LABEL        Invalid_Wiring_Priority_Setting
  7.126  MATH         M[255]=1
  7.127  DISP         Yokogawa LS3300 Driver
  7.127  DISP
  7.127  DISP         ERROR...!
  7.127  DISP         Wiring priority setting incorrectly specified.
  7.128  JMPL         EXIT_SUB

  7.129  LABEL        Invalid_Command_String
  7.130  MATH         M[255]=1
  7.131  DISP         Yokogawa LS3300 Driver
  7.131  DISP
  7.131  DISP         ERROR...!
  7.131  DISP         Invalid Command String.
  7.132  JMPL         EXIT_SUB

  7.133  LABEL        Invalid_Freq_value
  7.134  MATH         M[255]=1
  7.135  DISP         Yokogawa LS3300 Driver
  7.135  DISP
  7.135  DISP         ERROR...!
  7.135  DISP         Frequency exceeds upper or lower limits.
  7.136  JMPL         EXIT_SUB

  7.137  LABEL        Invalid_LEVR_Field
  7.138  MATH         M[255]=1
  7.139  DISP         Yokogawa LS3300 Driver
  7.139  DISP
  7.139  DISP         ERROR...!
  7.139  DISP         Level Ratio exceeds upper or lower limits.
  7.140  JMPL         EXIT_SUB

  7.141  LABEL        Invalid_Voltage_LRATIO
  7.142  MATH         M[255]=1
  7.143  DISP         Yokogawa LS3300 Driver
  7.143  DISP
  7.143  DISP         ERROR...!
  7.143  DISP         Voltage Level Ratio exceeds upper or lower limits.
  7.144  JMPL         EXIT_SUB

  7.145  LABEL        Invalid_Current_LRATIO
  7.146  MATH         M[255]=1
  7.147  DISP         Yokogawa LS3300 Driver
  7.147  DISP
  7.147  DISP         ERROR...!
  7.147  DISP         Current Level Ratio exceeds upper or lower limits.
  7.148  JMPL         EXIT_SUB
#----------------------------------------------

  7.149  LABEL        EXIT_SUB
  7.150  MATH         M[252] =1
  7.151  MATH         @PHASE  = "NULL"
  7.152  MATH         @LRATIO = "VRATIO100:CRATIO100"
  #7.128  MATH         MEM2    = ""
  7.153  MATH         MEM2 = S[32]

  7.154  IF           M[255] == 1
  7.155  ASK-                                          X Z           L
  7.156  EVAL   -e M[255] ==0:Syntax or specifications error on command string
  8.001  MATH         MEM1 = 0
  8.002  MATH         MEM= M[253]
  8.003  MATH         MEM1 = M[254]
  8.004  END
  8.005  ELSEIF       M[255] == -1
  8.006  MATH         MEM1 = 0
  8.007  MATH         MEM= M[253]
  8.008  MATH         MEM1 = M[254]
  8.009  END
  8.010  ELSEIF       M[255]==0
	#    Embedded IF statement
  8.011  IF           CMPI(MODE, "P")==1
  8.012  IEEE         :SOURCE:POWER:OUTPUT? [I]
  8.013  MATH         MEM1 = MEM
  8.014  ELSEIF       (CMPI(MODE, "C")==1)||(CMPI(MODE, "CX")==1)
  8.015  IEEE         :SOURCE:CURRENT:OUTPUT? [I]
  8.016  MATH         MEM1 = MEM
  8.017  ELSEIF       CMPI(MODE, "V")==1
  8.018  IEEE         :SOURCE:VOLTAGE:OUTPUT? [I]
  8.019  MATH         MEM1 = MEM
  8.020  ELSEIF       CMPI(MODE, "PX")==1
  8.021  MATH         MEM1 = M[254]
  8.022  ENDIF
	#    End of embedded IF statement
  8.023  MATH         MEM= M[253]
  8.024  END
  8.025  ENDIF

#----------------------------------------------
